==> ets-gmljpx20-1.0-sources.jar: org/opengis/cite/gmljpx20/ErrorMessageKeys.java <==
package org.opengis.cite.gmljpx20;

/**
 * Defines keys used to access localized messages for assertion errors. The
 * messages are stored in Properties files that are encoded in ISO-8859-1
 * (Latin-1). For some languages the {@code native2ascii} tool must be used to
 * process the files and produce escaped Unicode characters.
 */
public class ErrorMessageKeys {

    public static final String NOT_SCHEMA_VALID = "NotSchemaValid";
    public static final String XPATH_RESULT = "XPathResult";
    public static final String NAMESPACE_NAME = "NamespaceName";
    public static final String LOCAL_NAME = "LocalName";
    public static final String XML_ERROR = "XMLError";
    public static final String XPATH_ERROR = "XPathError";
    public static final String UNEXPECTED_STATUS = "UnexpectedStatus";
    public static final String XML_BOX_NOT_FOUND = "XmlBoxNotFound";
    public static final String FILETYPE_NOT_FOUND = "FileTypeNotFound";
    public static final String RESOURCE_REQUIREMENTS_NOT_FOUND = "ResourceRequirementsNotFound";
    public static final String GMLJP2_GMLCOV = "gmljp2-gmlcov";
    public static final String GMLJP2_GMLCOV_METADATA_HIGH = "gmljp2-gmlcov-metadata-coherence";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_METADATA = "gmljp2-gmlcov-precedence-metadata";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_DOMAIN_SET = "gmljp2-gmlcov-precedence-domainset";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_RANGE_TYPE = "gmljp2-gmlcov-precedence-rangetype";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_COHERENCE1 = "gmljp2-gmlcov-precedence-coherence1";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_COHERENCE2 = "gmljp2-gmlcov-precedence-coherence2";
    public static final String GMLJP2_GMLCOV_INSTEAD_METADATAPROPERTY = "gmljp2-gmlcov-metadata-property";
    public static final String GMLJP2_GMLCOV_CRS_RECTIFIED_GRID = "gmljp2-gmlcov-crs";
    public static final String GMLJP2_GMLCOV_CRS_HTTP = "gmljp2-gmlcov-crs-http";
    public static final String GMLJP2_GMLCOV_CRS_UNDEFINED = "gmljp2-gmlcov-crs-undefined";
    public static final String GMLJP2_GMLCOV_DATARECORDS_SWEUOM = "gmljp2-gmlcov-datarecords-swe-uom";
    public static final String GMLJP2_GMLCOV_UOM_HTTP = "gmljp2-gmlcov-uom-http";
    public static final String GMLJP2_GMLCOV_NIL_VALUES = "gmljp2-gmlcov-nil-values";
    public static final String GMLJP2_GMLCOV_NIL_VALUES_BY_REF_HTTP = "gmljp2-gmlcov-nil-values-byref-http";
    public static final String GMLJP2_GMLCOV_COVERAGE_COLLECTION = "gmljp2-gmlcov-coverage-collection";
    public static final String GMLJP2_GMLCOV_COVERAGE_COLLECTION_ELEMENT = "gmljp2-gmlcov-coverage-collection-element";
    public static final String GMLJP2_GMLCOV_COVERAGE_CONTAINER_ELEMENT = "gmljp2-gmlcov-coverage-container-element";
    public static final String GMLJP2_GMLCOV_METADATA = "gmljp2-gmlcov-metadata";
    public static final String GMLJP2_GMLCOV_FEATURES_ANNOTATION = "gmljp2-gmlcov-features-annotation";
    public static final String GMLJP2_ANNOTATION_CONTAINER = "gmljp2-annotation-container";
    public static final String GMLJP2_STYLE_CONTAINER = "gmljp2-style-container";
    public static final String GMLJP2_GMLCOV_FILENAME_CODESTREAM = "gmljp2-gmlcov-filename-codestream";
    public static final String GMLJP2_XML_NOT_SIGNALLED_CORRECTLY = "gmljp2-xml-not-signalled-correctly";
    public static final String GMLJP2_JPX_COMPATILITY = "gmljp2-jpx-compatibility";
    public static final String GMLJP2_JP2_COMPATILITY = "gmljp2-jp2-compatibility";
    public static final String GMLJP2_GMLDATA_EXISTS = "gmljp2-gmldata-exists";
    public static final String GMLJP2_TEST_STRUCTURE_XMLBOX = "gmljp2-test-structure-xmlbox";
    public static final String GMLJP2_SCHEMA_LOCATION = "gmljp2-schema-location";
    public static final String GMLJP2_INTERNAL_REF_TO_XML_BOX = "gmljp2-internal-ref-to-xml-box";
    public static final String GMLJP2_INTERNAL_REF_TO_CODESTREAM = "gmljp2-internal-ref-to-codestream";
}

==> ets-gmljpx20-1.2-sources.jar: org/opengis/cite/gmljpx20/ErrorMessageKeys.java <==
package org.opengis.cite.gmljpx20;

/**
 * Defines keys used to access localized messages for assertion errors. The
 * messages are stored in Properties files that are encoded in ISO-8859-1
 * (Latin-1). For some languages the {@code native2ascii} tool must be used to
 * process the files and produce escaped Unicode characters.
 */
public class ErrorMessageKeys {

    public static final String NOT_SCHEMA_VALID = "NotSchemaValid";
    public static final String XPATH_RESULT = "XPathResult";
    public static final String NAMESPACE_NAME = "NamespaceName";
    public static final String LOCAL_NAME = "LocalName";
    public static final String XML_ERROR = "XMLError";
    public static final String XPATH_ERROR = "XPathError";
    public static final String UNEXPECTED_STATUS = "UnexpectedStatus";
    public static final String XML_BOX_NOT_FOUND = "XmlBoxNotFound";
    public static final String FILETYPE_NOT_FOUND = "FileTypeNotFound";
    public static final String RESOURCE_REQUIREMENTS_NOT_FOUND = "ResourceRequirementsNotFound";
    public static final String GMLJP2_GMLCOV = "gmljp2-gmlcov";
    public static final String GMLJP2_GMLCOV_METADATA_HIGH = "gmljp2-gmlcov-metadata-coherence";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_METADATA = "gmljp2-gmlcov-precedence-metadata";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_DOMAIN_SET = "gmljp2-gmlcov-precedence-domainset";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_RANGE_TYPE = "gmljp2-gmlcov-precedence-rangetype";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_COHERENCE1 = "gmljp2-gmlcov-precedence-coherence1";
    public static final String GMLJP2_GMLCOV_PRECEDENCE_COHERENCE2 = "gmljp2-gmlcov-precedence-coherence2";
    public static final String GMLJP2_GMLCOV_INSTEAD_METADATAPROPERTY = "gmljp2-gmlcov-metadata-property";
    public static final String GMLJP2_GMLCOV_CRS_RECTIFIED_GRID = "gmljp2-gmlcov-crs";
    public static final String GMLJP2_GML_GEOGRAPHIC_FEATURES = "gml-geographicFeatures";
    public static final String GMLJP2_GMLCOV_CRS_HTTP = "gmljp2-gmlcov-crs-http";
    public static final String GMLJP2_GMLCOV_CRS_UNDEFINED = "gmljp2-gmlcov-crs-undefined";
    public static final String GMLJP2_GMLCOV_DATARECORDS_SWEUOM = "gmljp2-gmlcov-datarecords-swe-uom";
    public static final String GMLJP2_GMLCOV_UOM_HTTP = "gmljp2-gmlcov-uom-http";
    public static final String GMLJP2_GMLCOV_NIL_VALUES = "gmljp2-gmlcov-nil-values";
    public static final String GMLJP2_GMLCOV_NIL_VALUES_BY_REF_HTTP = "gmljp2-gmlcov-nil-values-byref-http";
    public static final String GMLJP2_GMLCOV_COVERAGE_COLLECTION = "gmljp2-gmlcov-coverage-collection";
    public static final String GMLJP2_GMLCOV_COVERAGE_COLLECTION_ELEMENT = "gmljp2-gmlcov-coverage-collection-element";
    public static final String GMLJP2_GMLCOV_COVERAGE_CONTAINER_ELEMENT = "gmljp2-gmlcov-coverage-container-element";
    public static final String GMLJP2_GMLCOV_METADATA = "gmljp2-gmlcov-metadata";
    public static final String GMLJP2_GMLCOV_FEATURES_ANNOTATION = "gmljp2-gmlcov-features-annotation";
    public static final String GMLJP2_ANNOTATION_CONTAINER = "gmljp2-annotation-container";
    public static final String GMLJP2_STYLE_CONTAINER = "gmljp2-style-container";
    public static final String GMLJP2_GMLCOV_FILENAME_CODESTREAM = "gmljp2-gmlcov-filename-codestream";
    public static final String GMLJP2_XML_NOT_SIGNALLED_CORRECTLY = "gmljp2-xml-not-signalled-correctly";
    public static final String GMLJP2_JPX_COMPATILITY = "gmljp2-jpx-compatibility";
    public static final String GMLJP2_JP2_COMPATILITY = "gmljp2-jp2-compatibility";
    public static final String GMLJP2_GMLDATA_EXISTS = "gmljp2-gmldata-exists";
    public static final String GMLJP2_TEST_STRUCTURE_XMLBOX = "gmljp2-test-structure-xmlbox";
    public static final String GMLJP2_SCHEMA_LOCATION = "gmljp2-schema-location";
    public static final String GMLJP2_EXTERNAL_REFS = "gmljp2-external-references";
    public static final String GMLJP2_INTERNAL_REFERENCES = "gmljp2-internal-references";
    public static final String GMLJP2_INTERNAL_REF_TO_XML_BOX = "gmljp2-internal-ref-to-xml-box";
    public static final String GMLJP2_INTERNAL_REF_TO_CODESTREAM = "gmljp2-internal-ref-to-codestream";
}
